.. Copyright (C) 2019 Rainer 'rei' Schuth <devel@reixd.net>
.. Copyright (C) 2019 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

Description
===========

The ``debops.postldap`` Ansible role can be used to configure and
manage a `Postfix` Virtual Mail server with an LDAP backend.
It allows configuration of Postfix using Ansible inventory variables.
